#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Apr 12 10:57:08 2023

@author: aguerrero
"""
import json
import os 
import datetime


 
def get_absolute_date_and_hour():
    now = datetime.datetime.utcnow()
    absolute_date = now.date()
    absolute_hour = str(now.time().hour)+":"+str( now.time().minute)+":"+str( now.time().second)
    return absolute_date, absolute_hour

def write_log(file_path,message,status,location,code):
    
    [date,hour]=get_absolute_date_and_hour()
    error={
            "description": message,
            "hour": hour,
            "date": date.strftime("%d/%m/%Y"),
            "type": status,
            "locator":location,
            "code":code
        }
    
    file_dir= os.path.dirname(file_path)
    if os.path.isdir(file_dir): 
        if not os.path.isfile(file_path):
            try:
                with open (file_path,"w+") as file:
                    json.dump(error,file, indent=4)
                file.close()
            except Exception as e:
                print(e)
        else: 
            try:
                with open (file_path, 'a+') as file:
                    json.dump(error,file,indent=4)
                file.close()
            except Exception as e:
                print(e)
    else:
        print(file_path)
        print (message)
        print("FATAL ERROR:log_file dir does not exist")
        os.sys.exit()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jul  3 17:36:41 2023

@author: aguerrero
"""

import pathlib
from setuptools import find_packages, setup

HERE = pathlib.Path(__file__).parent

VERSION = '1.1.0' #First version 
PACKAGE_NAME = 'dtcv2_util' #For DTGEO general 
AUTHOR = 'Alejandra Guerrero - DTGEO' 
AUTHOR_EMAIL = 'aguerrero@geo3bcn.csic.es' 
URL = 'https://gitlab.geo3bcn.csic.es/dtgeo/dtc-v2/meteo-gfs' 
LICENSE = 'MIT' 
DESCRIPTION = 'Library for workflow management' #DTC-V2
LONG_DESCRIPTION = (HERE / "README.md").read_text(encoding='utf-8') #Referencia al documento README con una descripción más elaborada
LONG_DESC_TYPE = "text/markdown"


#Required packages (automatically installed if they are not installed)
INSTALL_REQUIRES = [
      'datetime',
      'xarray',
      'requests',
      'netcdf4',
      
      ]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type=LONG_DESC_TYPE,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=INSTALL_REQUIRES,
    license=LICENSE,
    packages=find_packages(),
    package_data={
      PACKAGE_NAME: ['resources/*'],},
    include_package_data=True
)
